==> libbpp-phyl_2.0.3.orig.tar.gz: bpp-phyl-2.0.3/src/Bpp/Phyl/Mapping/OneJumpSubstitutionCount.cpp <==
//
// File: OneJumpSubstitutionCount.cpp
// Created by: Julien Dutheil
// Created on: Tue Nov 24 17:00 2009
//

/*
Copyright or © or Copr. CNRS, (November 16, 2004)

This software is a computer program whose purpose is to provide classes
for phylogenetic data analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "OneJumpSubstitutionCount.h"

using namespace bpp;

Matrix<double>* OneJumpSubstitutionCount::getAllNumbersOfSubstitutions(double length, unsigned int type) const
{
  tmp_ = model_->getPij_t(length);
  unsigned int n = model_->getNumberOfStates();
  Matrix<double>* probs = new LinearMatrix<double>(n, n);
  for (unsigned int i = 0; i < n; i++) 
    for (unsigned int j = 0; j < n; j++)
      (*probs)(i, j) = (i == j ? 1. - tmp_(i, j) : 1.);
  return probs;
}

==> libbpp-phyl_2.1.0.orig.tar.gz: bpp-phyl-2.1.0/src/Bpp/Phyl/Mapping/OneJumpSubstitutionCount.cpp <==
//
// File: OneJumpSubstitutionCount.cpp
// Created by: Julien Dutheil
// Created on: Tue Nov 24 17:00 2009
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)

This software is a computer program whose purpose is to provide classes
for phylogenetic data analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "OneJumpSubstitutionCount.h"

using namespace bpp;

Matrix<double>* OneJumpSubstitutionCount::getAllNumbersOfSubstitutions(double length, size_t type) const
{
  tmp_ = model_->getPij_t(length);
  size_t n = model_->getNumberOfStates();
  Matrix<double>* probs = new LinearMatrix<double>(n, n);
  for (size_t i = 0; i < n; i++) 
    for (size_t j = 0; j < n; j++)
      (*probs)(i, j) = (i == j ? 1. - tmp_(i, j) : 1.);
  return probs;
}
